@@ -8,6 +8,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
 import aws_cdk.aws_cloudwatch
@@ -76,7 +78,7 @@ class EdgeFunction(
         architecture: typing.Optional[aws_cdk.aws_lambda.Architecture] = None,
         architectures: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.Architecture]] = None,
         code_signing_config: typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig] = None,
-        current_version_options: typing.Optional[aws_cdk.aws_lambda.VersionOptions] = None,
+        current_version_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.VersionOptions, typing.Dict[str, typing.Any]]] = None,
         dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
         dead_letter_topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
@@ -91,7 +93,7 @@ class EdgeFunction(
         insights_version: typing.Optional[aws_cdk.aws_lambda.LambdaInsightsVersion] = None,
         layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
         log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
-        log_retention_retry_options: typing.Optional[aws_cdk.aws_lambda.LogRetentionRetryOptions] = None,
+        log_retention_retry_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.LogRetentionRetryOptions, typing.Dict[str, typing.Any]]] = None,
         log_retention_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
         memory_size: typing.Optional[jsii.Number] = None,
         profiling: typing.Optional[builtins.bool] = None,
@@ -103,7 +105,7 @@ class EdgeFunction(
         timeout: typing.Optional[aws_cdk.core.Duration] = None,
         tracing: typing.Optional[aws_cdk.aws_lambda.Tracing] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
         max_event_age: typing.Optional[aws_cdk.core.Duration] = None,
         on_failure: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
         on_success: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
@@ -154,6 +156,10 @@ class EdgeFunction(
         :param on_success: The destination for successful invocations. Default: - no destination
         :param retry_attempts: The maximum number of times to retry when the function returns an error. Minimum: 0 Maximum: 2 Default: 2
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EdgeFunction.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EdgeFunctionProps(
             stack_id=stack_id,
             code=code,
@@ -205,7 +211,7 @@ class EdgeFunction(
         self,
         alias_name: builtins.str,
         *,
-        additional_versions: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.VersionWeight]] = None,
+        additional_versions: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_lambda.VersionWeight, typing.Dict[str, typing.Any]]]] = None,
         description: typing.Optional[builtins.str] = None,
         provisioned_concurrent_executions: typing.Optional[jsii.Number] = None,
         max_event_age: typing.Optional[aws_cdk.core.Duration] = None,
@@ -224,6 +230,9 @@ class EdgeFunction(
         :param on_success: The destination for successful invocations. Default: - no destination
         :param retry_attempts: The maximum number of times to retry when the function returns an error. Minimum: 0 Maximum: 2 Default: 2
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EdgeFunction.add_alias)
+            check_type(argname="argument alias_name", value=alias_name, expected_type=type_hints["alias_name"])
         options = aws_cdk.aws_lambda.AliasOptions(
             additional_versions=additional_versions,
             description=description,
@@ -242,6 +251,9 @@ class EdgeFunction(
 
         :param source: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EdgeFunction.add_event_source)
+            check_type(argname="argument source", value=source, expected_type=type_hints["source"])
         return typing.cast(None, jsii.invoke(self, "addEventSource", [source]))
 
     @jsii.member(jsii_name="addEventSourceMapping")
@@ -261,7 +273,7 @@ class EdgeFunction(
         parallelization_factor: typing.Optional[jsii.Number] = None,
         report_batch_item_failures: typing.Optional[builtins.bool] = None,
         retry_attempts: typing.Optional[jsii.Number] = None,
-        source_access_configurations: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.SourceAccessConfiguration]] = None,
+        source_access_configurations: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_lambda.SourceAccessConfiguration, typing.Dict[str, typing.Any]]]] = None,
         starting_position: typing.Optional[aws_cdk.aws_lambda.StartingPosition] = None,
         tumbling_window: typing.Optional[aws_cdk.core.Duration] = None,
     ) -> aws_cdk.aws_lambda.EventSourceMapping:
@@ -284,6 +296,9 @@ class EdgeFunction(
         :param starting_position: The position in the DynamoDB, Kinesis or MSK stream where AWS Lambda should start reading. Default: - Required for Amazon Kinesis, Amazon DynamoDB, and Amazon MSK Streams sources.
         :param tumbling_window: The size of the tumbling windows to group records sent to DynamoDB or Kinesis. Default: - None
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EdgeFunction.add_event_source_mapping)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         options = aws_cdk.aws_lambda.EventSourceMappingOptions(
             batch_size=batch_size,
             bisect_batch_on_error=bisect_batch_on_error,
@@ -309,7 +324,7 @@ class EdgeFunction(
         self,
         *,
         auth_type: typing.Optional[aws_cdk.aws_lambda.FunctionUrlAuthType] = None,
-        cors: typing.Optional[aws_cdk.aws_lambda.FunctionUrlCorsOptions] = None,
+        cors: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionUrlCorsOptions, typing.Dict[str, typing.Any]]] = None,
     ) -> aws_cdk.aws_lambda.FunctionUrl:
         '''Adds a url to this lambda function.
 
@@ -344,6 +359,9 @@ class EdgeFunction(
         :param source_account: The AWS account ID (without hyphens) of the source owner. For example, if you specify an S3 bucket in the SourceArn property, this value is the bucket owner's account ID. You can use this property to ensure that all source principals are owned by a specific account.
         :param source_arn: The ARN of a resource that is invoking your function. When granting Amazon Simple Storage Service (Amazon S3) permission to invoke your function, specify this property with the bucket ARN as its value. This ensures that events generated only from the specified bucket, not just any bucket from any AWS account that creates a mapping to your function, can invoke the function.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EdgeFunction.add_permission)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         permission = aws_cdk.aws_lambda.Permission(
             principal=principal,
             action=action,
@@ -362,6 +380,9 @@ class EdgeFunction(
 
         :param statement: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EdgeFunction.add_to_role_policy)
+            check_type(argname="argument statement", value=statement, expected_type=type_hints["statement"])
         return typing.cast(None, jsii.invoke(self, "addToRolePolicy", [statement]))
 
     @jsii.member(jsii_name="configureAsyncInvoke")
@@ -398,6 +419,9 @@ class EdgeFunction(
 
         :param identity: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EdgeFunction.grant_invoke)
+            check_type(argname="argument identity", value=identity, expected_type=type_hints["identity"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantInvoke", [identity]))
 
     @jsii.member(jsii_name="grantInvokeUrl")
@@ -409,6 +433,9 @@ class EdgeFunction(
 
         :param identity: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EdgeFunction.grant_invoke_url)
+            check_type(argname="argument identity", value=identity, expected_type=type_hints["identity"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantInvokeUrl", [identity]))
 
     @jsii.member(jsii_name="metric")
@@ -439,6 +466,9 @@ class EdgeFunction(
         :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
         :param unit: Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EdgeFunction.metric)
+            check_type(argname="argument metric_name", value=metric_name, expected_type=type_hints["metric_name"])
         props = aws_cdk.aws_cloudwatch.MetricOptions(
             account=account,
             color=color,
@@ -784,7 +814,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         architecture: typing.Optional[aws_cdk.aws_lambda.Architecture] = None,
         architectures: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.Architecture]] = None,
         code_signing_config: typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig] = None,
-        current_version_options: typing.Optional[aws_cdk.aws_lambda.VersionOptions] = None,
+        current_version_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.VersionOptions, typing.Dict[str, typing.Any]]] = None,
         dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
         dead_letter_topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
@@ -799,7 +829,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         insights_version: typing.Optional[aws_cdk.aws_lambda.LambdaInsightsVersion] = None,
         layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
         log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
-        log_retention_retry_options: typing.Optional[aws_cdk.aws_lambda.LogRetentionRetryOptions] = None,
+        log_retention_retry_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.LogRetentionRetryOptions, typing.Dict[str, typing.Any]]] = None,
         log_retention_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
         memory_size: typing.Optional[jsii.Number] = None,
         profiling: typing.Optional[builtins.bool] = None,
@@ -811,7 +841,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         timeout: typing.Optional[aws_cdk.core.Duration] = None,
         tracing: typing.Optional[aws_cdk.aws_lambda.Tracing] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
         code: aws_cdk.aws_lambda.Code,
         handler: builtins.str,
         runtime: aws_cdk.aws_lambda.Runtime,
@@ -890,6 +920,49 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
             log_retention_retry_options = aws_cdk.aws_lambda.LogRetentionRetryOptions(**log_retention_retry_options)
         if isinstance(vpc_subnets, dict):
             vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
+        if __debug__:
+            type_hints = typing.get_type_hints(EdgeFunctionProps.__init__)
+            check_type(argname="argument max_event_age", value=max_event_age, expected_type=type_hints["max_event_age"])
+            check_type(argname="argument on_failure", value=on_failure, expected_type=type_hints["on_failure"])
+            check_type(argname="argument on_success", value=on_success, expected_type=type_hints["on_success"])
+            check_type(argname="argument retry_attempts", value=retry_attempts, expected_type=type_hints["retry_attempts"])
+            check_type(argname="argument allow_all_outbound", value=allow_all_outbound, expected_type=type_hints["allow_all_outbound"])
+            check_type(argname="argument allow_public_subnet", value=allow_public_subnet, expected_type=type_hints["allow_public_subnet"])
+            check_type(argname="argument architecture", value=architecture, expected_type=type_hints["architecture"])
+            check_type(argname="argument architectures", value=architectures, expected_type=type_hints["architectures"])
+            check_type(argname="argument code_signing_config", value=code_signing_config, expected_type=type_hints["code_signing_config"])
+            check_type(argname="argument current_version_options", value=current_version_options, expected_type=type_hints["current_version_options"])
+            check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
+            check_type(argname="argument dead_letter_queue_enabled", value=dead_letter_queue_enabled, expected_type=type_hints["dead_letter_queue_enabled"])
+            check_type(argname="argument dead_letter_topic", value=dead_letter_topic, expected_type=type_hints["dead_letter_topic"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
+            check_type(argname="argument environment_encryption", value=environment_encryption, expected_type=type_hints["environment_encryption"])
+            check_type(argname="argument ephemeral_storage_size", value=ephemeral_storage_size, expected_type=type_hints["ephemeral_storage_size"])
+            check_type(argname="argument events", value=events, expected_type=type_hints["events"])
+            check_type(argname="argument filesystem", value=filesystem, expected_type=type_hints["filesystem"])
+            check_type(argname="argument function_name", value=function_name, expected_type=type_hints["function_name"])
+            check_type(argname="argument initial_policy", value=initial_policy, expected_type=type_hints["initial_policy"])
+            check_type(argname="argument insights_version", value=insights_version, expected_type=type_hints["insights_version"])
+            check_type(argname="argument layers", value=layers, expected_type=type_hints["layers"])
+            check_type(argname="argument log_retention", value=log_retention, expected_type=type_hints["log_retention"])
+            check_type(argname="argument log_retention_retry_options", value=log_retention_retry_options, expected_type=type_hints["log_retention_retry_options"])
+            check_type(argname="argument log_retention_role", value=log_retention_role, expected_type=type_hints["log_retention_role"])
+            check_type(argname="argument memory_size", value=memory_size, expected_type=type_hints["memory_size"])
+            check_type(argname="argument profiling", value=profiling, expected_type=type_hints["profiling"])
+            check_type(argname="argument profiling_group", value=profiling_group, expected_type=type_hints["profiling_group"])
+            check_type(argname="argument reserved_concurrent_executions", value=reserved_concurrent_executions, expected_type=type_hints["reserved_concurrent_executions"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument security_group", value=security_group, expected_type=type_hints["security_group"])
+            check_type(argname="argument security_groups", value=security_groups, expected_type=type_hints["security_groups"])
+            check_type(argname="argument timeout", value=timeout, expected_type=type_hints["timeout"])
+            check_type(argname="argument tracing", value=tracing, expected_type=type_hints["tracing"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument vpc_subnets", value=vpc_subnets, expected_type=type_hints["vpc_subnets"])
+            check_type(argname="argument code", value=code, expected_type=type_hints["code"])
+            check_type(argname="argument handler", value=handler, expected_type=type_hints["handler"])
+            check_type(argname="argument runtime", value=runtime, expected_type=type_hints["runtime"])
+            check_type(argname="argument stack_id", value=stack_id, expected_type=type_hints["stack_id"])
         self._values: typing.Dict[str, typing.Any] = {
             "code": code,
             "handler": handler,
